<?php
namespace PAGEmachine\Ats\Controller\Application;

use PAGEmachine\Ats\Application\ApplicationStatus;
use PAGEmachine\Ats\Domain\Model\ApplicationA;
use PAGEmachine\Ats\Domain\Model\Job;
use PAGEmachine\Ats\Domain\Repository\ApplicationARepository;

/*
 * This file is part of the PAGEmachine ATS project.
 */

/**
 * FormController (First Step)
 */
class FormController extends AbstractApplicationController
{
    /**
     * @var ApplicationARepository
     */
    protected $applicationARepository = null;

    /**
     * @param  ApplicationARepository $repository
     */
    public function injectApplicationARepository(ApplicationARepository $applicationARepository)
    {
        $this->applicationARepository = $applicationARepository;
    }

    /**
     * starts a new application form
     *
     * @param  Job $job
     * @param  ApplicationA|null $application
     * @TYPO3\CMS\Extbase\Annotation\IgnoreValidation("application")
     * @ignorevalidation $application
     * @return void
     */
    public function formAction(Job $job, ApplicationA $application = null)
    {

        if ($application == null) {
            $application = $this->applicationARepository->findByUserAndJob($this->authenticationService->getAuthenticatedUser(), $job, null, ApplicationStatus::INCOMPLETE);
        }

        $this->view->assignMultiple([
            "job" => $job,
            "application" => $application,
            "user" => $this->authenticationService->getAuthenticatedUser(),
            ]);
    }

    /**
     *
     * @param  ApplicationA $application
     * @validate $application \PAGEmachine\Ats\Domain\Validator\TypoScriptValidator
     * @return void
     */
    public function updateFormAction(ApplicationA $application)
    {

        $this->applicationARepository->addOrUpdate($application);

        $this->forward("editPersonalData", "Application\\PersonalData", null, ['application' => $application->getUid()]);
    }
}
